@@ -453,7 +453,9 @@ class TemplateGenerator(object):
                     resource.add_parameter(volume_parameter_name, description,
                                            default=server_volume['id'])
             if server_volumes:
-                properties['block_device_mapping'] = server_volumes
+                # block_device_mapping_v2 is the new way of associating
+                # block devices to an instance
+                properties['block_device_mapping_v2'] = server_volumes
 
             resources.append(resource)
         return resources
@@ -525,13 +527,11 @@ class TemplateGenerator(object):
                     "Snapshot to create volume %s from" % resource_name)
                 resource.add_parameter(key, description,
                                        default=volume.snapshot_id)
-            try:
-                if volume.display_name:
-                    properties['name'] = volume.display_name
-                if volume.display_description:
-                    properties['description'] = volume.display_description
-            except AttributeError:
-                pass
+            if hasattr(volume, 'display_name') and volume.display_name:
+                properties['name'] = volume.display_name
+            if (hasattr(volume, 'display_description') and
+               volume.display_description):
+                properties['description'] = volume.display_description
             if volume.volume_type and volume.volume_type != 'None':
                 key = "%s_volume_type" % resource_name
                 description = (
