@@ -48,6 +48,16 @@ class FakeVolume(FakeBase):
     metadata = None
 
 
+class FakeUnnamedVolume(FakeBase):
+    id = 1234
+    size = 1
+    source_volid = None
+    bootable = 'false'
+    snapshot_id = None
+    volume_type = 'fast'
+    metadata = None
+
+
 class FakeServer(FakeBase):
     id = '1234'
     name = 'server1'
@@ -1280,6 +1290,29 @@ class VolumeTests(BaseTestCase):
         self.check_template(generator._extract_volumes(), expected_resources,
                             expected_parameters)
 
+    def test_basic_unnamed(self):
+        self.fake.volumes = [FakeUnnamedVolume(), ]
+        generator = self.get_generator(False, False, False, True)
+
+        expected_parameters = {
+            'volume_0_volume_type': {
+                'default': 'fast',
+                'description': 'Volume type for volume volume_0',
+                'type': 'string'}
+        }
+
+        expected_resources = {
+            'volume_0': {
+                'type': 'OS::Cinder::Volume',
+                'properties': {
+                    'volume_type': {'get_param': 'volume_0_volume_type'},
+                    'size': 1
+                }
+            }
+        }
+        self.check_template(generator._extract_volumes(), expected_resources,
+                            expected_parameters)
+
     def test_source_volid_external(self):
         self.fake.volumes = [FakeVolume(source_volid=5678), ]
         generator = self.get_generator(False, False, False, True)
@@ -1579,7 +1612,7 @@ class ServerTests(BaseTestCase):
                     'diskConfig': 'MANUAL',
                     'flavor': {'get_param': 'server_0_flavor'},
                     'key_name': {'get_resource': 'key_0'},
-                    'block_device_mapping': [{'volume_id': {
+                    'block_device_mapping_v2': [{'volume_id': {
                         'get_resource': 'volume_0'}, 'device_name': 'vda'}]
                 }
             }
@@ -1623,7 +1656,7 @@ class ServerTests(BaseTestCase):
                     'flavor': {'get_param': 'server_0_flavor'},
                     'image': {'get_param': 'server_0_image'},
                     'key_name': {'get_resource': 'key_0'},
-                    'block_device_mapping': [{'volume_id': {
+                    'block_device_mapping_v2': [{'volume_id': {
                         'get_resource': 'volume_0'}, 'device_name':
                         '/dev/vdb'}]
                 }
@@ -1829,7 +1862,7 @@ class ServerTests(BaseTestCase):
                     'flavor': {'get_param': 'server_0_flavor'},
                     'image': {'get_param': 'server_0_image'},
                     'key_name': {'get_resource': 'key_0'},
-                    'block_device_mapping': [{'volume_id': {
+                    'block_device_mapping_v2': [{'volume_id': {
                         'get_param': 'volume_server1_0'}, 'device_name':
                         '/dev/vdb'}]
                 }
